@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'uri'
 
 class RedirectUriValidator < ActiveModel::EachValidator
@@ -34,11 +36,12 @@ class RedirectUriValidator < ActiveModel::EachValidator
 
   def invalid_ssl_uri?(uri)
     forces_ssl = Doorkeeper.configuration.force_ssl_in_redirect_uri
+    non_https = uri.try(:scheme) == 'http'
 
     if forces_ssl.respond_to?(:call)
-      forces_ssl.call(uri)
+      forces_ssl.call(uri) && non_https
     else
-      forces_ssl && uri.try(:scheme) == 'http'
+      forces_ssl && non_https
     end
   end
 end
