@@ -2,18 +2,28 @@ require 'doorkeeper/version'
 require 'doorkeeper/engine'
 require 'doorkeeper/config'
 
+require 'doorkeeper/request/strategy'
+require 'doorkeeper/request/authorization_code'
+require 'doorkeeper/request/client_credentials'
+require 'doorkeeper/request/code'
+require 'doorkeeper/request/password'
+require 'doorkeeper/request/refresh_token'
+require 'doorkeeper/request/token'
+
 require 'doorkeeper/errors'
 require 'doorkeeper/server'
 require 'doorkeeper/request'
 require 'doorkeeper/validations'
 
 require 'doorkeeper/oauth/authorization/code'
+require 'doorkeeper/oauth/authorization/context'
 require 'doorkeeper/oauth/authorization/token'
 require 'doorkeeper/oauth/authorization/uri_builder'
 require 'doorkeeper/oauth/helpers/scope_checker'
 require 'doorkeeper/oauth/helpers/uri_checker'
 require 'doorkeeper/oauth/helpers/unique_token'
 
+require 'doorkeeper/oauth'
 require 'doorkeeper/oauth/scopes'
 require 'doorkeeper/oauth/error'
 require 'doorkeeper/oauth/base_response'
@@ -25,6 +35,13 @@ require 'doorkeeper/oauth/base_request'
 require 'doorkeeper/oauth/authorization_code_request'
 require 'doorkeeper/oauth/refresh_token_request'
 require 'doorkeeper/oauth/password_access_token_request'
+
+require 'doorkeeper/oauth/client_credentials/validation'
+require 'doorkeeper/oauth/client_credentials/creator'
+require 'doorkeeper/oauth/client_credentials/issuer'
+require 'doorkeeper/oauth/client_credentials/validation'
+require 'doorkeeper/oauth/client/credentials'
+
 require 'doorkeeper/oauth/client_credentials_request'
 require 'doorkeeper/oauth/code_request'
 require 'doorkeeper/oauth/token_request'
@@ -49,26 +66,12 @@ require 'doorkeeper/helpers/controller'
 require 'doorkeeper/rails/routes'
 require 'doorkeeper/rails/helpers'
 
+require 'doorkeeper/rake'
+require 'doorkeeper/stale_records_cleaner'
+
 require 'doorkeeper/orm/active_record'
 
-require 'active_support/deprecation'
-
 module Doorkeeper
-  def self.configured?
-    ActiveSupport::Deprecation.warn "Method `Doorkeeper#configured?` has been deprecated without replacement."
-    @config.present?
-  end
-
-  def self.database_installed?
-    ActiveSupport::Deprecation.warn "Method `Doorkeeper#database_installed?` has been deprecated without replacement."
-    [AccessToken, AccessGrant, Application].all?(&:table_exists?)
-  end
-
-  def self.installed?
-    ActiveSupport::Deprecation.warn "Method `Doorkeeper#installed?` has been deprecated without replacement."
-    configured? && database_installed?
-  end
-
   def self.authenticate(request, methods = Doorkeeper.configuration.access_token_methods)
     OAuth::Token.authenticate(request, *methods)
   end
