@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'doorkeeper/grape/authorization_decorator'
 
 module Doorkeeper
@@ -31,7 +33,7 @@ module Doorkeeper
       end
 
       def doorkeeper_token
-        @_doorkeeper_token ||= OAuth::Token.authenticate(
+        @doorkeeper_token ||= OAuth::Token.authenticate(
           decorated_request,
           *Doorkeeper.configuration.access_token_methods
         )
