@@ -1,8 +1,12 @@
+# frozen_string_literal: true
+
 module Doorkeeper
   module OAuth
     class BaseRequest
       include Validations
 
+      attr_reader :grant_type
+
       def authorize
         validate
 
@@ -17,11 +21,7 @@ module Doorkeeper
       end
 
       def scopes
-        @scopes ||= if @original_scopes.present?
-                      OAuth::Scopes.from_string(@original_scopes)
-                    else
-                      default_scopes
-                    end
+        @scopes ||= build_scopes
       end
 
       def default_scopes
@@ -33,12 +33,13 @@ module Doorkeeper
       end
 
       def find_or_create_access_token(client, resource_owner_id, scopes, server)
+        context = Authorization::Token.build_context(client, grant_type, scopes)
         @access_token = AccessToken.find_or_create_for(
           client,
           resource_owner_id,
           scopes,
-          Authorization::Token.access_token_expires_in(server, client),
-          server.refresh_token_enabled?
+          Authorization::Token.access_token_expires_in(server, context),
+          Authorization::Token.refresh_token_enabled?(server, context)
         )
       end
 
@@ -47,8 +48,20 @@ module Doorkeeper
       end
 
       def after_successful_response
-        Doorkeeper.configuration.after_successful_strategy_response.
-          call(self, @response)
+        Doorkeeper.configuration.after_successful_strategy_response.call(self, @response)
+      end
+
+      private
+
+      def build_scopes
+        if @original_scopes.present?
+          OAuth::Scopes.from_string(@original_scopes)
+        else
+          client_scopes = @client.try(:scopes)
+          return default_scopes if client_scopes.blank?
+
+          default_scopes & @client.scopes
+        end
       end
     end
   end
