@@ -1,4 +1,4 @@
-require 'doorkeeper/oauth/client/credentials'
+# frozen_string_literal: true
 
 module Doorkeeper
   module OAuth
