@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Doorkeeper
   module OAuth
     class ClientCredentialsRequest < BaseRequest
@@ -5,7 +7,8 @@ module Doorkeeper
         def call(client, scopes, attributes = {})
           AccessToken.find_or_create_for(
             client, nil, scopes, attributes[:expires_in],
-            attributes[:use_refresh_token])
+            attributes[:use_refresh_token]
+          )
         end
       end
     end
