@@ -1,4 +1,4 @@
-require 'doorkeeper/oauth/client_credentials/validation'
+# frozen_string_literal: true
 
 module Doorkeeper
   module OAuth
@@ -25,7 +25,12 @@ module Doorkeeper
         private
 
         def create_token(client, scopes, creator)
-          ttl = Authorization::Token.access_token_expires_in(@server, client)
+          context = Authorization::Token.build_context(
+            client,
+            Doorkeeper::OAuth::CLIENT_CREDENTIALS,
+            scopes
+          )
+          ttl = Authorization::Token.access_token_expires_in(@server, context)
 
           creator.call(
             client,
