@@ -1,6 +1,4 @@
-require 'doorkeeper/validations'
-require 'doorkeeper/oauth/scopes'
-require 'doorkeeper/oauth/helpers/scope_checker'
+# frozen_string_literal: true
 
 module Doorkeeper
   module OAuth
@@ -13,7 +11,9 @@ module Doorkeeper
         validate :scopes, error: :invalid_scope
 
         def initialize(server, request)
-          @server, @request, @client = server, request, request.client
+          @server = server
+          @request = request
+          @client = request.client
 
           validate
         end
@@ -25,7 +25,7 @@ module Doorkeeper
         end
 
         def validate_scopes
-          return true unless @request.scopes.present?
+          return true if @request.scopes.blank?
 
           application_scopes = if @client.present?
                                  @client.application.scopes
