@@ -1,6 +1,4 @@
-require 'doorkeeper/oauth/client_credentials/creator'
-require 'doorkeeper/oauth/client_credentials/issuer'
-require 'doorkeeper/oauth/client_credentials/validation'
+# frozen_string_literal: true
 
 module Doorkeeper
   module OAuth
