@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Doorkeeper
   module OAuth
     module Helpers
@@ -17,10 +19,6 @@ module Doorkeeper
               @valid_scopes.has_scopes?(parsed_scopes)
           end
 
-          def match?
-            valid? && parsed_scopes.has_scopes?(@valid_scopes)
-          end
-
           private
 
           def valid_scopes(server_scopes, application_scopes)
@@ -35,10 +33,6 @@ module Doorkeeper
         def self.valid?(scope_str, server_scopes, application_scopes = nil)
           Validator.new(scope_str, server_scopes, application_scopes).valid?
         end
-
-        def self.match?(scope_str, server_scopes, application_scopes = nil)
-          Validator.new(scope_str, server_scopes, application_scopes).match?
-        end
       end
     end
   end
