@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Doorkeeper
   module OAuth
     class Scopes
@@ -41,7 +43,7 @@ module Doorkeeper
       end
 
       def has_scopes?(scopes)
-        scopes.all? { |s| exists?(s) }
+        scopes.all? { |scope| exists?(scope) }
       end
 
       def +(other)
