@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Doorkeeper
   module OAuth
     # RFC7662 OAuth 2.0 Token Introspection
@@ -47,12 +49,12 @@ module Doorkeeper
 
       # Client Authentication
       def authorized_client
-        @_authorized_client ||= server.credentials && server.client
+        @authorized_client ||= server.credentials && server.client
       end
 
       # Bearer Token Authentication
       def authorized_token
-        @_authorized_token ||=
+        @authorized_token ||=
           OAuth::Token.authenticate(server.context.request, :from_bearer_authorization)
       end
 
