@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Doorkeeper
   module OAuth
     class TokenResponse
@@ -23,9 +25,11 @@ module Doorkeeper
       end
 
       def headers
-        { 'Cache-Control' => 'no-store',
+        {
+          'Cache-Control' => 'no-store',
           'Pragma' => 'no-cache',
-          'Content-Type' => 'application/json; charset=utf-8' }
+          'Content-Type' => 'application/json; charset=utf-8'
+        }
       end
     end
   end
