@@ -1,6 +1,5 @@
 class HomeController < ApplicationController
-  def index
-  end
+  def index; end
 
   def sign_in
     session[:user_id] = if Rails.env.development?
