@@ -2,24 +2,24 @@ FactoryBot.define do
   factory :access_grant, class: Doorkeeper::AccessGrant do
     sequence(:resource_owner_id) { |n| n }
     application
-    redirect_uri 'https://app.com/callback'
-    expires_in 100
-    scopes 'public write'
+    redirect_uri { 'https://app.com/callback' }
+    expires_in { 100 }
+    scopes { 'public write' }
   end
 
   factory :access_token, class: Doorkeeper::AccessToken do
     sequence(:resource_owner_id) { |n| n }
     application
-    expires_in 2.hours
+    expires_in { 2.hours }
 
     factory :clientless_access_token do
-      application nil
+      application { nil }
     end
   end
 
   factory :application, class: Doorkeeper::Application do
     sequence(:name) { |n| "Application #{n}" }
-    redirect_uri 'https://app.com/callback'
+    redirect_uri { 'https://app.com/callback' }
   end
 
   # do not name this factory :user, otherwise it will conflict with factories
