@@ -1,4 +1,4 @@
-require 'spec_helper_integration'
+require 'spec_helper'
 
 describe Doorkeeper::DashboardHelper do
   describe '#doorkeeper_errors_for' do
