@@ -1,6 +1,4 @@
 require 'spec_helper'
-require 'active_support/core_ext/object/blank'
-require 'doorkeeper/models/concerns/revocable'
 
 describe 'Revocable' do
   subject do
