@@ -1,8 +1,4 @@
 require 'spec_helper'
-require 'active_support/core_ext/module/delegation'
-require 'active_support/core_ext/object/blank'
-require 'doorkeeper/oauth/scopes'
-require 'doorkeeper/models/concerns/scopes'
 
 describe 'Doorkeeper::Models::Scopes' do
   subject do
