@@ -1,4 +1,4 @@
-require 'spec_helper_integration'
+require 'spec_helper'
 
 module Doorkeeper::OAuth
   describe ClientCredentialsRequest do
@@ -20,7 +20,7 @@ module Doorkeeper::OAuth
         request = ClientCredentialsRequest.new(server, nil, {})
         expect do
           request.authorize
-        end.to_not change { Doorkeeper::AccessToken.count }
+        end.to_not(change { Doorkeeper::AccessToken.count })
       end
     end
   end
