@@ -1,4 +1,4 @@
-require 'spec_helper_integration'
+require 'spec_helper'
 
 module Doorkeeper
   describe Application do
@@ -206,6 +206,19 @@ module Doorkeeper
       end
     end
 
+    describe :revoke_tokens_and_grants_for do
+      it 'revokes all access tokens and access grants' do
+        application_id = 42
+        resource_owner = double
+        expect(Doorkeeper::AccessToken)
+          .to receive(:revoke_all_for).with(application_id, resource_owner)
+        expect(Doorkeeper::AccessGrant)
+          .to receive(:revoke_all_for).with(application_id, resource_owner)
+
+        Application.revoke_tokens_and_grants_for(application_id, resource_owner)
+      end
+    end
+
     describe :by_uid_and_secret do
       context "when application is private/confidential" do
         it "finds the application via uid/secret" do
@@ -253,51 +266,5 @@ module Doorkeeper
         it { expect(subject).to eq(false) }
       end
     end
-
-    describe :confidential do
-      subject { FactoryBot.create(:application, confidential: confidential).confidential }
-
-      context 'when application is private/confidential' do
-        let(:confidential) { true }
-        it { expect(subject).to eq(true) }
-      end
-
-      context 'when application is public/non-confidential' do
-        let(:confidential) { false }
-        it { expect(subject).to eq(false) }
-      end
-
-      context 'when the application does not support confidentiality' do
-        let(:confidential) { false }
-
-        before { allow(Application).to receive(:supports_confidentiality?).and_return(false) }
-
-        it 'warns of the CVE' do
-          expect(ActiveSupport::Deprecation).to receive(:warn).with(
-            'You are susceptible to security bug ' \
-            'CVE-2018-1000211. Please follow instructions outlined in ' \
-            'Doorkeeper::CVE_2018_1000211_WARNING'
-          )
-          Application.new.confidential
-        end
-
-        it { expect(subject).to eq(true) }
-      end
-    end
-
-    describe :supports_confidentiality? do
-      context 'when no column' do
-        it 'returns false' do
-          expect(Application).to receive(:column_names).and_return(%w[foo bar])
-          expect(Application.supports_confidentiality?).to eq(false)
-        end
-      end
-      context 'when column' do
-        it 'returns true' do
-          expect(Application).to receive(:column_names).and_return(%w[foo bar confidential])
-          expect(Application.supports_confidentiality?).to eq(true)
-        end
-      end
-    end
   end
 end
