@@ -1,4 +1,4 @@
-require 'spec_helper_integration'
+require 'spec_helper'
 
 feature 'Authorization Code Flow Errors' do
   let(:client_params) { {} }
@@ -57,7 +57,7 @@ describe 'Authorization Code Flow Errors', 'after authorization' do
     # Second attempt with same token
     expect do
       post token_endpoint_url(code: @authorization.token, client: @client)
-    end.to_not change { Doorkeeper::AccessToken.count }
+    end.to_not(change { Doorkeeper::AccessToken.count })
 
     should_not_have_json 'access_token'
     should_have_json 'error', 'invalid_grant'
