@@ -1,6 +1,6 @@
-require 'spec_helper_integration'
+require 'spec_helper'
 
-describe 'Doorkeeper version' do
+describe Doorkeeper::VERSION do
   context '#gem_version' do
     it 'returns Gem::Version instance' do
       expect(Doorkeeper.gem_version).to be_an_instance_of(Gem::Version)
@@ -9,7 +9,7 @@ describe 'Doorkeeper version' do
 
   context 'VERSION' do
     it 'returns gem version string' do
-      expect(Doorkeeper::VERSION::STRING).to match(/^\d+\.\d+\.\d+[.\w]?$/)
+      expect(Doorkeeper::VERSION::STRING).to match(/^\d+\.\d+\.\d+(\.\w+)?$/)
     end
   end
 end
